@@ -5,7 +5,7 @@ use v6;
 role PDF::Class::Type[$type-entry = 'Type', $subtype-entry = 'Subtype'] {
 
     use PDF::Class::Loader;
-    use PDF::DAO;
+    use PDF::COS;
     #| enforce tie-ins between /Type, /Subtype & the class name. e.g.
     #| PDF::Catalog should have /Type = /Catalog
     method type    is rw { self{$type-entry} }
@@ -18,7 +18,7 @@ role PDF::Class::Type[$type-entry = 'Type', $subtype-entry = 'Subtype'] {
             if $class-name ~~ /^ 'PDF::' (\w+) ['::' (\w+)]? $/ {
                 my Str $type-name = ~$0;
 
-		my $type = self.type //= PDF::DAO.coerce( :name($type-name) );
+		my $type = self.type //= PDF::COS.coerce( :name($type-name) );
 
 		# /Type already set. check it agrees with the class name
 		die "conflict between class-name $class-name ($type-name) and dictionary /$type-entry /{self{$type-entry}}"
@@ -26,7 +26,7 @@ role PDF::Class::Type[$type-entry = 'Type', $subtype-entry = 'Subtype'] {
 
                 if $1 {
                     my Str $subtype-name = ~$1;
-		    my $subtype = self.subtype //= PDF::DAO.coerce( :name($subtype-name) );
+		    my $subtype = self.subtype //= PDF::COS.coerce( :name($subtype-name) );
 
 		    # /Subtype already set. check it agrees with the class name
 		    die "conflict between class-name $class-name ($subtype-name) and dictionary /$subtype-entry /{self{$subtype-entry}}"
