@@ -12,5 +12,5 @@ class PDF::Font::Type0
 	subset NameOrCMap of PDF::COS where PDF::COS::Name | PDF::CMap;
         has NameOrCMap $.Encoding is entry(:required);   #| (Required) The name of a predefined CMap, or a stream containing a CMap that maps character codes to font numbers and CIDs.
 	has PDF::Font @.DescendantFonts is entry(:required,:len(1));    #| (Required) A one-element array specifying the CIDFont dictionary that is the descendant of this Type 0 font.
-        has PDF::COS::Stream $.ToUnicode is entry;         #| (Optional) A stream containing a CMap file that maps character codes to Unicode values
+        has PDF::CMap $.ToUnicode is entry;         #| (Optional) A stream containing a CMap file that maps character codes to Unicode values
 }
