@@ -6,19 +6,19 @@ class PDF::Font::Type3
     is PDF::Font
     does PDF::Content::Resourced {
 
-    use PDF::DAO::Tie;
-    use PDF::DAO::Dict;
-    use PDF::DAO::Name;
-    use PDF::DAO::Stream;
+    use PDF::COS::Tie;
+    use PDF::COS::Dict;
+    use PDF::COS::Name;
+    use PDF::COS::Stream;
 
     # see [PDF 1.7 TABLE 5.9 Entries in a Type 3 font dictionary]
-    has PDF::DAO::Name $.Name is entry;                 #| (Required in PDF 1.0; optional otherwise) See Table 5.8 on page 413
+    has PDF::COS::Name $.Name is entry;                 #| (Required in PDF 1.0; optional otherwise) See Table 5.8 on page 413
     has Numeric @.FontBBox is entry(:required, :len(4));         #| (Required) A rectangle (see Section 3.8.4, “Rectangles”) expressed in the glyph coordinate system, specifying the font bounding box.
     has Numeric @.FontMatrix is entry(:required, :len(6));       #| (Required) An array of six numbers specifying the font matrix, mapping glyph space to text space
-    has PDF::DAO::Stream %.CharProcs is entry(:required);        #| (Required) A dictionary in which each key is a character name and the value associated with that key is a content stream that constructs and paints the glyph for that character.
+    has PDF::COS::Stream %.CharProcs is entry(:required);        #| (Required) A dictionary in which each key is a character name and the value associated with that key is a content stream that constructs and paints the glyph for that character.
 
     use PDF::Encoding;
-    my subset NameOrEncoding where PDF::DAO::Name | PDF::Encodiing;
+    my subset NameOrEncoding where PDF::COS::Name | PDF::Encodiing;
     has NameOrEncoding $.Encoding is entry(:required); #| (Required) An encoding dictionary whose Differences array specifies the complete character encoding for this font
 
     has UInt $.FirstChar is entry(:required);          #| (Required) The first character code defined in the font’s Widths array
